@@ -24,8 +24,8 @@ import (
 )
 
 const (
-	emptyDisableError           = "You must specify an add-on name. Run `minishift addons list` to view installed add-ons."
-	noAddOnToDisableMessage     = "No add-on with the name %s is installed."
+	emptyDisableError           = "You must specify an add-on name. Run 'minishift addons list' to view installed add-ons."
+	noAddOnToDisableMessage     = "No add-on with the name '%s' is installed."
 	addOnAlreadyDisabledMessage = "Add-on '%s' is already disabled."
 )
 
@@ -58,7 +58,7 @@ func runDisableAddon(cmd *cobra.Command, args []string) {
 
 	addOnConfig, err := addOnManager.Disable(addOnName)
 	if err != nil {
-		atexit.ExitWithMessage(1, fmt.Sprintf("Unable to disable the add-on %s: %s", addOnName, err.Error()))
+		atexit.ExitWithMessage(1, fmt.Sprintf("Unable to disable the add-on '%s': %s", addOnName, err.Error()))
 	} else {
 		fmt.Println(fmt.Sprintf("Add-on '%s' disabled", addOnName))
 	}
