@@ -20,17 +20,22 @@ import (
 	"fmt"
 	"reflect"
 
+	"github.com/docker/machine/libmachine/drivers"
+	"github.com/docker/machine/libmachine/provision"
 	"github.com/minishift/minishift/cmd/minishift/cmd/config"
-	"github.com/minishift/minishift/pkg/minikube/constants"
+	"github.com/minishift/minishift/cmd/minishift/state"
 	"github.com/minishift/minishift/pkg/minishift/addon"
 	"github.com/minishift/minishift/pkg/minishift/addon/manager"
+	"github.com/minishift/minishift/pkg/minishift/docker"
+	"github.com/minishift/minishift/pkg/minishift/openshift"
 	"github.com/minishift/minishift/pkg/util/os/atexit"
+	"gopkg.in/yaml.v2"
 )
 
 // GetAddOnManager returns the addon manager
 func GetAddOnManager() *manager.AddOnManager {
 	addOnConfigs := GetAddOnConfiguration()
-	m, err := manager.NewAddOnManager(constants.MakeMiniPath("addons"), addOnConfigs)
+	m, err := manager.NewAddOnManager(state.InstanceDirs.Addons, addOnConfigs)
 	if err != nil {
 		atexit.ExitWithMessage(1, fmt.Sprintf("Cannot initialize the add-on manager: %s", err.Error()))
 	}
@@ -93,3 +98,28 @@ func RemoveAddOnFromConfig(addOnName string) {
 	delete(addOnConfigMap, addOnName)
 	WriteAddOnConfig(addOnConfigMap)
 }
+
+func determineRoutingSuffix(driver drivers.Driver) string {
+	defer func() {
+		if r := recover(); r != nil {
+			atexit.ExitWithMessage(1, "Cannot determine the routing suffix from the OpenShift master configuration.")
+		}
+	}()
+
+	sshCommander := provision.GenericSSHCommander{Driver: driver}
+	dockerCommander := docker.NewVmDockerCommander(sshCommander)
+
+	raw, err := openshift.ViewConfig(openshift.MASTER, dockerCommander)
+	if err != nil {
+		atexit.ExitWithMessage(1, fmt.Sprintf("Cannot get the OpenShift master configuration: %s", err.Error()))
+	}
+
+	var config map[interface{}]interface{}
+	err = yaml.Unmarshal([]byte(raw), &config)
+	if err != nil {
+		atexit.ExitWithMessage(1, fmt.Sprintf("Cannot parse the OpenShift master configuration: %s", err.Error()))
+	}
+
+	// making assumptions about the master config here. In case the config structure changes, the code might panic here
+	return config["routingConfig"].(map[interface{}]interface{})["subdomain"].(string)
+}
