@@ -20,15 +20,13 @@ package cmd
 
 import (
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 func Test_unix_oc_path(t *testing.T) {
 	shellConfig, err := getOcShellConfig("/Users/john/.minishift/cache/oc/v1.5.0/oc", "bash")
-	if err != nil {
-		t.Fatalf("Unexepcted error: %s", err)
-	}
-
-	if shellConfig.OcDirPath != "/Users/john/.minishift/cache/oc/v1.5.0" {
-		t.Fatalf("Unexepcted oc path: %s", shellConfig.OcDirPath)
-	}
+	assert.NoError(t, err)
+	expectedOcDirPath := "/Users/john/.minishift/cache/oc/v1.5.0"
+	assert.Equal(t, shellConfig.OcDirPath, expectedOcDirPath)
 }
