@@ -23,6 +23,7 @@ import (
 
 	"github.com/docker/machine/libmachine"
 	"github.com/minishift/minishift/cmd/minishift/cmd/util"
+	"github.com/minishift/minishift/cmd/minishift/state"
 	"github.com/minishift/minishift/pkg/minikube/constants"
 	"github.com/minishift/minishift/pkg/minishift/openshift"
 	"github.com/minishift/minishift/pkg/util/os/atexit"
@@ -38,7 +39,7 @@ var serviceListCmd = &cobra.Command{
 	Short: "Gets the URLs of the services in your local OpenShift cluster.",
 	Long:  `Gets the URLs of the services in your local OpenShift cluster.`,
 	Run: func(cmd *cobra.Command, args []string) {
-		api := libmachine.NewClient(constants.Minipath, constants.MakeMiniPath("certs"))
+		api := libmachine.NewClient(state.InstanceDirs.Home, state.InstanceDirs.Certs)
 		defer api.Close()
 
 		util.ExitIfUndefined(api, constants.MachineName)
