@@ -46,7 +46,6 @@ import (
 	"github.com/minishift/minishift/pkg/minishift/hostfolder"
 	minishiftNetwork "github.com/minishift/minishift/pkg/minishift/network"
 	"github.com/minishift/minishift/pkg/minishift/openshift"
-	openshiftVersion "github.com/minishift/minishift/pkg/minishift/openshift/version"
 	profileActions "github.com/minishift/minishift/pkg/minishift/profile"
 	"github.com/minishift/minishift/pkg/minishift/provisioner"
 	"github.com/minishift/minishift/pkg/util"
@@ -62,6 +61,7 @@ import (
 const (
 	commandName             = "start"
 	defaultInsecureRegistry = "172.30.0.0/16"
+	hostfoldersAutoMountKey = "hostfolders-automount"
 )
 
 var (
@@ -70,9 +70,8 @@ var (
 	shellProxyEnv           string
 	unsupportedIsoUrlFormat = fmt.Sprintf("Unsupported value for iso-url. It can be a URL, file URI or one of the following aliases: [%s].",
 		strings.Join(minishiftConstants.ValidIsoAliases, ","))
-)
 
-var (
+	// custom flags variable
 	dockerEnvFlag = &flag.Flag{
 		Name:      configCmd.DockerEnv.Name,
 		Shorthand: "",
@@ -100,28 +99,35 @@ var (
 		Usage:     "Registry mirrors to pass to the Docker daemon.",
 		Value:     cmdUtil.NewStringSliceValue([]string{}, &[]string{}),
 	}
-)
 
-// startCmd represents the start command
-var startCmd *cobra.Command
+	nameServersFlag = &flag.Flag{
+		Name:      configCmd.NameServers.Name,
+		Shorthand: "",
+		Usage:     "Specify nameserver to use for the instance.",
+		Value:     cmdUtil.NewStringSliceValue([]string{}, &[]string{}),
+	}
 
-// Set default value for host data and config dir
-var (
+	startCmd *cobra.Command
+
+	// Set default value for host data and config dir
 	hostConfigDirectory  = "/var/lib/minishift/openshift.local.config"
 	hostDataDirectory    = "/var/lib/minishift/hostdata"
 	hostVolumesDirectory = "/var/lib/minishift/openshift.local.volumes"
 	hostPvDirectory      = "/var/lib/minishift/openshift.local.pv"
+
+	// clusterUpFlagSet contains the command line switches which needs to be passed on to 'cluster up'
+	clusterUpFlagSet *flag.FlagSet
+
+	// minishiftToClusterUp is a mapping between flag names used in minishift CLI and flag name as passed to 'cluster up'
+	minishiftToClusterUp = map[string]string{
+		"openshift-env": "env",
+		"ocp-tag":       "version",
+	}
+
+	// ocPath
+	ocPath = ""
 )
 
-// clusterUpFlagSet contains the command line switches which needs to be passed on to 'cluster up'
-var clusterUpFlagSet *flag.FlagSet
-
-// minishiftToClusterUp is a mapping between flag names used in minishift CLI and flag name as passed to 'cluster up'
-var minishiftToClusterUp = map[string]string{
-	"openshift-env": "env",
-	"ocp-tag":       "version",
-}
-
 // init configures the command line options of this command
 func init() {
 	// need to initialize startCmd in init to avoid initialization loop (runStart calls validateOpenshiftVersion
@@ -156,7 +162,7 @@ func runStart(cmd *cobra.Command, args []string) {
 	defer libMachineClient.Close()
 
 	ensureNotRunning(libMachineClient, constants.MachineName)
-	validateOpenshiftVersion()
+	addVersionPrefixToOpenshiftVersion()
 
 	// to determine whether we need to run post cluster up actions,
 	// we need to determine whether this is a restart prior to potentially creating a new VM
@@ -165,6 +171,11 @@ func runStart(cmd *cobra.Command, args []string) {
 	// preflight check (before start)
 	preflightChecksBeforeStartingHost()
 
+	// Cache OC binary before starting the VM and perform oc command option check
+	requestedOpenShiftVersion := viper.GetString(configCmd.OpenshiftVersion.Name)
+	ocPath = cmdUtil.CacheOc(clusterup.DetermineOcVersion(requestedOpenShiftVersion))
+	preflightChecksForArtifacts()
+
 	setSubscriptionManagerParameters()
 
 	proxyConfig := handleProxies()
@@ -174,6 +185,9 @@ func runStart(cmd *cobra.Command, args []string) {
 	hostVm := startHost(libMachineClient)
 	registrationUtil.RegisterHost(libMachineClient)
 
+	// Forcibly set nameservers when configured
+	minishiftNetwork.AddNameserversToInstance(hostVm.Driver, getSlice(configCmd.NameServers.Name))
+
 	// preflight checks (after start)
 	preflightChecksAfterStartingHost(hostVm.Driver)
 
@@ -197,12 +211,10 @@ func runStart(cmd *cobra.Command, args []string) {
 
 	autoMountHostFolders(hostVm.Driver)
 
-	requestedOpenShiftVersion := viper.GetString(configCmd.OpenshiftVersion.Name)
 	if !isRestart {
 		importContainerImages(hostVm.Driver, libMachineClient, requestedOpenShiftVersion)
 	}
 
-	ocPath := cmdUtil.CacheOc(clusterup.DetermineOcVersion(requestedOpenShiftVersion))
 	clusterUpConfig := &clusterup.ClusterUpConfig{
 		OpenShiftVersion: requestedOpenShiftVersion,
 		MachineName:      constants.MachineName,
@@ -238,7 +250,7 @@ func runStart(cmd *cobra.Command, args []string) {
 	if isRestart {
 		err = cmdUtil.SetOcContext(minishiftConfig.AllInstancesConfig.ActiveProfile)
 		if err != nil {
-			fmt.Println(fmt.Sprintf("Could not set oc CLI context for: %s", profileActions.GetActiveProfile()))
+			fmt.Println(fmt.Sprintf("Could not set oc CLI context for: '%s'", profileActions.GetActiveProfile()))
 		}
 	}
 }
@@ -247,7 +259,7 @@ func runStart(cmd *cobra.Command, args []string) {
 // On subsequent VM restarts these actions can be skipped.
 func postClusterUp(hostVm *host.Host, clusterUpConfig *clusterup.ClusterUpConfig) {
 	sshCommander := provision.GenericSSHCommander{Driver: hostVm.Driver}
-	err := clusterup.PostClusterUp(clusterUpConfig, sshCommander, addon.GetAddOnManager())
+	err := clusterup.PostClusterUp(clusterUpConfig, sshCommander, addon.GetAddOnManager(), &util.RealRunner{})
 	if err != nil {
 		atexit.ExitWithMessage(1, fmt.Sprintf("Error during post cluster up configuration: %v", err))
 	}
@@ -328,6 +340,8 @@ func startHost(libMachineClient *libmachine.Client) *host.Host {
 		HostOnlyCIDR:     viper.GetString(configCmd.HostOnlyCIDR.Name),
 		ShellProxyEnv:    shellProxyEnv,
 	}
+	minishiftConfig.InstanceConfig.VMDriver = machineConfig.VMDriver
+	minishiftConfig.InstanceConfig.Write()
 
 	fmt.Printf(" using '%s' hypervisor ...\n", machineConfig.VMDriver)
 	var hostVm *host.Host
@@ -341,21 +355,7 @@ func startHost(libMachineClient *libmachine.Client) *host.Host {
 		fmt.Println("   Disk size:", units.HumanSize(float64(machineConfig.DiskSize*units.MB)))
 	}
 
-	// Experimental features
-	if minishiftConfig.EnableExperimental {
-		networkSettings := minishiftNetwork.NetworkSettings{
-			Device:    viper.GetString(configCmd.NetworkDevice.Name),
-			IPAddress: viper.GetString(configCmd.IPAddress.Name),
-			Netmask:   viper.GetString(configCmd.Netmask.Name),
-			Gateway:   viper.GetString(configCmd.Gateway.Name),
-			DNS1:      viper.GetString(configCmd.NameServer.Name),
-		}
-
-		// Configure networking on startup only works on Hyper-V
-		if networkSettings.IPAddress != "" {
-			minishiftNetwork.ConfigureNetworking(constants.MachineName, machineConfig.VMDriver, networkSettings)
-		}
-	}
+	configureNetworkSettings()
 
 	cacheMinishiftISO(machineConfig)
 
@@ -379,10 +379,41 @@ func startHost(libMachineClient *libmachine.Client) *host.Host {
 	return hostVm
 }
 
-func autoMountHostFolders(driver drivers.Driver) {
-	if hostfolder.IsAutoMount() && hostfolder.IsHostfoldersDefined() {
-		hostfolder.MountHostfolders(driver)
+func configureNetworkSettings() {
+	networkSettings := minishiftNetwork.NetworkSettings{
+		Device:    viper.GetString(configCmd.NetworkDevice.Name),
+		IPAddress: viper.GetString(configCmd.IPAddress.Name),
+		Netmask:   viper.GetString(configCmd.Netmask.Name),
+		Gateway:   viper.GetString(configCmd.Gateway.Name),
 	}
+
+	nameservers := getSlice(configCmd.NameServers.Name)
+	if len(nameservers) > 0 {
+		networkSettings.DNS1 = nameservers[0]
+	}
+	if len(nameservers) > 1 {
+		networkSettings.DNS2 = nameservers[1]
+	}
+
+	// Configure networking on startup only works on Hyper-V
+	if networkSettings.IPAddress != "" {
+		minishiftNetwork.ConfigureNetworking(constants.MachineName, networkSettings)
+	}
+}
+
+func autoMountHostFolders(driver drivers.Driver) {
+	hostFolderManager, err := hostfolder.NewManager(minishiftConfig.InstanceConfig, minishiftConfig.AllInstancesConfig)
+	if err != nil {
+		atexit.ExitWithMessage(1, err.Error())
+	}
+	if isAutoMount() && hostFolderManager.ExistAny() {
+		fmt.Println("-- Mounting host folders")
+		hostFolderManager.MountAll(driver)
+	}
+}
+
+func isAutoMount() bool {
+	return viper.GetBool(hostfoldersAutoMountKey)
 }
 
 func addActiveProfileInformation() {
@@ -538,13 +569,13 @@ func initStartFlags() *flag.FlagSet {
 	startFlagSet.AddFlag(registryMirrorFlag)
 	startFlagSet.AddFlag(cmdUtil.AddOnEnvFlag)
 
-	if minishiftConfig.EnableExperimental && runtime.GOOS == "windows" {
-		startFlagSet.String(configCmd.NetworkDevice.Name, "eth0", "Specify the network device to use for the IP address. Ignored if no IP address specified (experimental - Hyper-V only)")
-		startFlagSet.String(configCmd.IPAddress.Name, "", "Specify IP address to assign to the instance (experimental - Hyper-V only)")
-		startFlagSet.String(configCmd.Netmask.Name, "24", "Specify netmask to use for the IP address. Ignored if no IP address specified (experimental - Hyper-V only)")
-		startFlagSet.String(configCmd.Gateway.Name, "", "Specify gateway to use for the instance. Ignored if no IP address specified (experimental - Hyper-V only)")
-		startFlagSet.String(configCmd.NameServer.Name, "8.8.8.8", "Specify nameserver to use for the instance. Ignored if no IP address specified (experimental - Hyper-V only)")
+	if runtime.GOOS == "windows" {
+		startFlagSet.String(configCmd.NetworkDevice.Name, "", "Specify the network device to use for the IP address. Ignored if no IP address specified (Hyper-V only)")
+		startFlagSet.String(configCmd.IPAddress.Name, "", "Specify IP address to assign to the instance (Hyper-V only)")
+		startFlagSet.String(configCmd.Netmask.Name, "", "Specify netmask to use for the IP address. Ignored if no IP address specified (Hyper-V only)")
+		startFlagSet.String(configCmd.Gateway.Name, "", "Specify gateway to use for the instance. Ignored if no IP address specified (Hyper-V only)")
 	}
+	startFlagSet.AddFlag(nameServersFlag)
 
 	if minishiftConfig.EnableExperimental {
 		startFlagSet.String(configCmd.ISOUrl.Name, minishiftConstants.B2dIsoAlias, "Location of the minishift ISO. Can be an URL, file URI or one of the following short names: [b2d centos minikube].")
@@ -559,7 +590,6 @@ func initStartFlags() *flag.FlagSet {
 func initClusterUpFlags() *flag.FlagSet {
 	clusterUpFlagSet := flag.NewFlagSet(commandName, flag.ContinueOnError)
 
-	//clusterUpFlagSet.StringVar(&clusterUpConfig.Image, "image", "openshift/origin", "Specify the images to use for OpenShift")
 	clusterUpFlagSet.Bool(configCmd.SkipRegistryCheck.Name, false, "Skip the Docker daemon registry check.")
 	clusterUpFlagSet.String(configCmd.PublicHostname.Name, "", "Public hostname of the OpenShift cluster.")
 	clusterUpFlagSet.String(configCmd.RoutingSuffix.Name, "", "Default suffix for the server routes.")
@@ -569,14 +599,14 @@ func initClusterUpFlags() *flag.FlagSet {
 	clusterUpFlagSet.String(configCmd.HostPvDir.Name, hostPvDirectory, "Directory on Docker host for OpenShift persistent volumes")
 	clusterUpFlagSet.Int(configCmd.ServerLogLevel.Name, 0, "Log level for the OpenShift server.")
 	clusterUpFlagSet.StringSliceVarP(&openShiftEnv, configCmd.OpenshiftEnv.Name, "e", []string{}, "Specify key-value pairs of environment variables to set on the OpenShift container.")
-	clusterUpFlagSet.Bool(configCmd.Metrics.Name, false, "Install metrics (experimental)")
-	clusterUpFlagSet.Bool(configCmd.Logging.Name, false, "Install logging (experimental)")
 	clusterUpFlagSet.String(configCmd.OpenshiftVersion.Name, version.GetOpenShiftVersion(), fmt.Sprintf("The OpenShift Container Platform version to run, eg. %s. Check the available tags in https://access.redhat.com/containers/?tab=tags#/registry.access.redhat.com/openshift3/ose", version.GetOpenShiftVersion()))
 	clusterUpFlagSet.String(configCmd.NoProxyList.Name, "", "List of hosts or subnets for which no proxy should be used.")
 	clusterUpFlagSet.AddFlag(cmdUtil.HttpProxyFlag)
 	clusterUpFlagSet.AddFlag(cmdUtil.HttpsProxyFlag)
 
 	if minishiftConfig.EnableExperimental {
+		clusterUpFlagSet.Bool(configCmd.Metrics.Name, false, "Install metrics (experimental)")
+		clusterUpFlagSet.Bool(configCmd.Logging.Name, false, "Install logging (experimental)")
 		clusterUpFlagSet.Bool(configCmd.ServiceCatalog.Name, false, "Install service catalog (experimental)")
 		clusterUpFlagSet.String(configCmd.ExtraClusterUpFlags.Name, "", "Specify optional flags for use with 'cluster up' (unsupported)")
 	}
@@ -589,7 +619,7 @@ func initSubscriptionManagerFlags() *flag.FlagSet {
 	subscriptionManagerFlagSet := flag.NewFlagSet(commandName, flag.ContinueOnError)
 	subscriptionManagerFlagSet.String(configCmd.Username.Name, "", "Username for the virtual machine registration.")
 	subscriptionManagerFlagSet.String(configCmd.Password.Name, "", "Password for the virtual machine registration.")
-	subscriptionManagerFlagSet.BoolVar(&registrationUtil.SkipRegistration, configCmd.SkipRegistration.Name, false, "Skip the virtual machine registration.")
+	subscriptionManagerFlagSet.Bool(configCmd.SkipRegistration.Name, false, "Skip the virtual machine registration.")
 
 	return subscriptionManagerFlagSet
 }
@@ -644,22 +674,9 @@ func ensureNotRunning(client *libmachine.Client, machineName string) {
 	}
 }
 
-func validateOpenshiftVersion() {
+// Make sure the version actually has a 'v' prefix. See https://github.com/minishift/minishift/issues/410
+func addVersionPrefixToOpenshiftVersion() {
 	requestedVersion := viper.GetString(configCmd.OpenshiftVersion.Name)
-
-	valid, err := openshiftVersion.IsGreaterOrEqualToBaseVersion(requestedVersion, constants.MinimumSupportedOpenShiftVersion)
-	if err != nil {
-		atexit.ExitWithMessage(1, err.Error())
-	}
-
-	if !valid {
-		fmt.Printf("Minishift does not support OpenShift version %s. "+
-			"You need to use a version >= %s\n", viper.GetString(configCmd.OpenshiftVersion.Name),
-			constants.MinimumSupportedOpenShiftVersion)
-		atexit.Exit(1)
-	}
-
-	// Make sure the version actually has a 'v' prefix. See https://github.com/minishift/minishift/issues/410
 	if !strings.HasPrefix(requestedVersion, constants.VersionPrefix) {
 		requestedVersion = constants.VersionPrefix + requestedVersion
 		// this will make sure the right version is set in case the version comes from config file
@@ -671,6 +688,7 @@ func validateOpenshiftVersion() {
 }
 
 func setSubscriptionManagerParameters() {
+	registrationUtil.SkipRegistration = viper.GetBool(configCmd.SkipRegistration.Name)
 	minishiftCluster.RegistrationParameters.Username = viper.GetString(configCmd.Username.Name)
 	minishiftCluster.RegistrationParameters.Password = viper.GetString(configCmd.Password.Name)
 	minishiftCluster.RegistrationParameters.IsTtySupported = util.IsTtySupported()
