@@ -22,40 +22,69 @@ import (
 	"os"
 	"os/exec"
 	"regexp"
-	"runtime"
 	"strconv"
 	"strings"
 
-	"github.com/minishift/minishift/pkg/util/filehelper"
-
 	"github.com/docker/machine/libmachine/drivers"
+	"github.com/golang/glog"
 	configCmd "github.com/minishift/minishift/cmd/minishift/cmd/config"
+	"github.com/minishift/minishift/pkg/minikube/constants"
 	validations "github.com/minishift/minishift/pkg/minishift/config"
+	"github.com/minishift/minishift/pkg/minishift/network"
 	"github.com/minishift/minishift/pkg/minishift/shell/powershell"
-	minishiftUtil "github.com/minishift/minishift/pkg/minishift/util"
+	"github.com/minishift/minishift/pkg/util"
+	"github.com/minishift/minishift/pkg/util/github"
 
 	"github.com/minishift/minishift/pkg/util/os/atexit"
 	"github.com/spf13/viper"
 
 	cmdUtils "github.com/minishift/minishift/cmd/minishift/cmd/util"
-	"github.com/minishift/minishift/pkg/minishift/constants"
+	minikubeConstants "github.com/minishift/minishift/pkg/minikube/constants"
+	minishiftNetwork "github.com/minishift/minishift/pkg/minishift/network"
+	openshiftVersion "github.com/minishift/minishift/pkg/minishift/openshift/version"
 	stringUtils "github.com/minishift/minishift/pkg/util/strings"
 )
 
 const (
-	StorageDisk = "/mnt/sda1"
+	StorageDisk   = "/mnt/?da1"
+	GithubAddress = "github.com:http"
 )
 
-// preflightChecksAfterStartingHost is executed before the startHost function.
+// preflightChecksBeforeStartingHost is executed before the startHost function.
 func preflightChecksBeforeStartingHost() {
 	driverErrorMessage := "See the 'Setting Up the Driver Plug-in' topic (https://docs.openshift.org/latest/minishift/getting-started/setting-up-driver-plugin.html) for more information"
 	prerequisiteErrorMessage := "See the 'Installing Prerequisites for Minishift' topic (https://docs.openshift.org/latest/minishift/getting-started/installing.html#install-prerequisites) for more information"
 
+	if network.CheckInternetConnectivity(GithubAddress) {
+		preflightCheckSucceedsOrFails(
+			configCmd.SkipCheckOpenShiftRelease.Name,
+			checkOCPRelease,
+			fmt.Sprintf("Checking if requested OpenShift version '%s' is valid", viper.GetString(configCmd.OpenshiftVersion.Name)),
+			configCmd.WarnCheckOpenShiftRelease.Name,
+			fmt.Sprintf("%s is not a valid OpenShift version", viper.GetString(configCmd.OpenshiftVersion.Name)),
+		)
+	} else {
+		fmt.Printf("-- Checking if requested OpenShift version '%s' is valid ... SKIP\n", viper.GetString(configCmd.OpenshiftVersion.Name))
+		if glog.V(2) {
+			fmt.Println("github.com is not accessible over internet or host is not connected to internet")
+		}
+	}
+
+	preflightCheckSucceedsOrFails(
+		configCmd.SkipCheckOpenShiftVersion.Name,
+		validateOpenshiftVersion,
+		fmt.Sprintf("Checking if requested OpenShift version '%s' is supported", viper.GetString(configCmd.OpenshiftVersion.Name)),
+		configCmd.WarnCheckOpenShiftVersion.Name,
+		fmt.Sprintf("Minishift does not support OpenShift version %s. "+
+			"You need to use a version >= %s\n", viper.GetString(configCmd.OpenshiftVersion.Name),
+			constants.MinimumSupportedOpenShiftVersion),
+	)
+
 	preflightCheckSucceedsOrFails(
 		configCmd.SkipCheckVMDriver.Name,
 		checkVMDriver,
 		fmt.Sprintf("Checking if requested hypervisor '%s' is supported on this platform", viper.GetString(configCmd.VmDriver.Name)),
-		false, configCmd.WarnCheckVMDriver.Name,
+		configCmd.WarnCheckVMDriver.Name,
 		driverErrorMessage)
 
 	switch viper.GetString(configCmd.VmDriver.Name) {
@@ -64,58 +93,58 @@ func preflightChecksBeforeStartingHost() {
 			configCmd.SkipCheckXHyveDriver.Name,
 			checkXhyveDriver,
 			"Checking if xhyve driver is installed",
-			false, configCmd.WarnCheckXHyveDriver.Name,
+			configCmd.WarnCheckXHyveDriver.Name,
 			driverErrorMessage)
 	case "kvm":
 		preflightCheckSucceedsOrFails(
 			configCmd.SkipCheckKVMDriver.Name,
 			checkKvmDriver,
 			"Checking if KVM driver is installed",
-			false, configCmd.WarnCheckKVMDriver.Name,
+			configCmd.WarnCheckKVMDriver.Name,
 			driverErrorMessage)
 		preflightCheckSucceedsOrFails(
 			configCmd.SkipCheckKVMDriver.Name,
 			checkLibvirtInstalled,
 			"Checking if Libvirt is installed",
-			false, configCmd.WarnCheckKVMDriver.Name,
+			configCmd.WarnCheckKVMDriver.Name,
 			driverErrorMessage)
 		preflightCheckSucceedsOrFails(
 			configCmd.SkipCheckKVMDriver.Name,
 			checkLibvirtDefaultNetworkExists,
 			"Checking if Libvirt default network is present",
-			false, configCmd.WarnCheckKVMDriver.Name,
+			configCmd.WarnCheckKVMDriver.Name,
 			driverErrorMessage)
 		preflightCheckSucceedsOrFails(
 			configCmd.SkipCheckKVMDriver.Name,
 			checkLibvirtDefaultNetworkActive,
 			"Checking if Libvirt default network is active",
-			true, configCmd.WarnCheckKVMDriver.Name,
+			configCmd.WarnCheckKVMDriver.Name,
 			driverErrorMessage)
 	case "hyperv":
 		preflightCheckSucceedsOrFails(
 			configCmd.SkipCheckHyperVDriver.Name,
 			checkHypervDriverInstalled,
 			"Checking if Hyper-V driver is installed",
-			false, configCmd.WarnCheckHyperVDriver.Name,
+			configCmd.WarnCheckHyperVDriver.Name,
 			driverErrorMessage)
 		preflightCheckSucceedsOrFails(
 			configCmd.SkipCheckHyperVDriver.Name,
 			checkHypervDriverSwitch,
 			"Checking if Hyper-V driver is configured to use a Virtual Switch",
-			false, configCmd.WarnCheckHyperVDriver.Name,
+			configCmd.WarnCheckHyperVDriver.Name,
 			driverErrorMessage)
 		preflightCheckSucceedsOrFails(
 			configCmd.SkipCheckHyperVDriver.Name,
 			checkHypervDriverUser,
 			"Checking if user is a member of the Hyper-V Administrators group",
-			false, configCmd.WarnCheckHyperVDriver.Name,
+			configCmd.WarnCheckHyperVDriver.Name,
 			driverErrorMessage)
 	case "virtualbox":
 		preflightCheckSucceedsOrFails(
 			configCmd.SkipCheckVBoxInstalled.Name,
 			checkVBoxInstalled,
 			"Checking if VirtualBox is installed",
-			false, configCmd.WarnCheckVBoxInstalled.Name,
+			configCmd.WarnCheckVBoxInstalled.Name,
 			prerequisiteErrorMessage)
 
 	}
@@ -124,7 +153,7 @@ func preflightChecksBeforeStartingHost() {
 		configCmd.SkipCheckIsoUrl.Name,
 		checkIsoURL,
 		"Checking the ISO URL",
-		false, configCmd.WarnCheckIsoUrl.Name,
+		configCmd.WarnCheckIsoUrl.Name,
 		"See the 'Basic Usage' topic (https://docs.openshift.org/latest/minishift/using/basic-usage.html) for more information")
 }
 
@@ -134,31 +163,37 @@ func preflightChecksAfterStartingHost(driver drivers.Driver) {
 		configCmd.SkipInstanceIP.Name,
 		checkInstanceIP, driver,
 		"Checking for IP address",
-		false, configCmd.WarnInstanceIP.Name,
+		configCmd.WarnInstanceIP.Name,
 		"Error determining IP address")
+	preflightCheckSucceedsOrFailsWithDriver(
+		configCmd.SkipCheckNameservers.Name,
+		checkNameservers, driver,
+		"Checking for nameservers",
+		configCmd.WarnCheckNameservers.Name,
+		"VM does not have any nameserver setup")
 	preflightCheckSucceedsOrFailsWithDriver(
 		configCmd.SkipCheckNetworkPing.Name,
 		checkIPConnectivity, driver,
 		"Checking if external host is reachable from the Minishift VM",
-		true, configCmd.WarnCheckNetworkPing.Name,
+		configCmd.WarnCheckNetworkPing.Name,
 		"VM is unable to ping external host")
 	preflightCheckSucceedsOrFailsWithDriver(
 		configCmd.SkipCheckNetworkHTTP.Name,
 		checkHttpConnectivity, driver,
 		"Checking HTTP connectivity from the VM",
-		true, configCmd.WarnCheckNetworkHTTP.Name,
+		configCmd.WarnCheckNetworkHTTP.Name,
 		"VM cannot connect to external URL with HTTP")
 	preflightCheckSucceedsOrFailsWithDriver(
 		configCmd.SkipCheckStorageMount.Name,
 		checkStorageMounted, driver,
 		"Checking if persistent storage volume is mounted",
-		false, configCmd.WarnCheckStorageMount.Name,
+		configCmd.WarnCheckStorageMount.Name,
 		"Persistent volume storage is not mounted")
 	preflightCheckSucceedsOrFailsWithDriver(
 		configCmd.SkipCheckStorageUsage.Name,
 		checkStorageUsage, driver,
 		"Checking available disk space",
-		false, configCmd.WarnCheckStorageUsage.Name,
+		configCmd.WarnCheckStorageUsage.Name,
 		"Insufficient disk space on the persistent storage volume")
 }
 
@@ -175,7 +210,7 @@ type preflightCheckWithDriverFunc func(driver drivers.Driver) bool
 // cause is. It takes configNameOverrideIfSkipped to allow skipping the test.
 // While treatAsWarning and configNameOverrideIfWarning can be used to make the
 // test to be treated as a warning instead.
-func preflightCheckSucceedsOrFails(configNameOverrideIfSkipped string, execute preflightCheckFunc, message string, treatAsWarning bool, configNameOverrideIfWarning string, errorMessage string) {
+func preflightCheckSucceedsOrFails(configNameOverrideIfSkipped string, execute preflightCheckFunc, message string, configNameOverrideIfWarning string, errorMessage string) {
 	fmt.Printf("-- %s ... ", message)
 
 	isConfiguredToSkip := viper.GetBool(configNameOverrideIfSkipped)
@@ -193,7 +228,7 @@ func preflightCheckSucceedsOrFails(configNameOverrideIfSkipped string, execute p
 
 	fmt.Println("FAIL")
 	errorMessage = fmt.Sprintf("   %s", errorMessage)
-	if isConfiguredToWarn || treatAsWarning {
+	if isConfiguredToWarn {
 		fmt.Println(errorMessage)
 	} else {
 		atexit.ExitWithMessage(1, errorMessage)
@@ -207,7 +242,7 @@ func preflightCheckSucceedsOrFails(configNameOverrideIfSkipped string, execute p
 // configNameOverrideIfSkipped to allow skipping the test. While treatAsWarning
 // and configNameOverrideIfWarning can be used to make the test to be treated as
 // a warning instead.
-func preflightCheckSucceedsOrFailsWithDriver(configNameOverrideIfSkipped string, execute preflightCheckWithDriverFunc, driver drivers.Driver, message string, treatAsWarning bool, configNameOverrideIfWarning string, errorMessage string) {
+func preflightCheckSucceedsOrFailsWithDriver(configNameOverrideIfSkipped string, execute preflightCheckWithDriverFunc, driver drivers.Driver, message string, configNameOverrideIfWarning string, errorMessage string) {
 	fmt.Printf("-- %s ... ", message)
 
 	isConfiguredToSkip := viper.GetBool(configNameOverrideIfSkipped)
@@ -225,7 +260,7 @@ func preflightCheckSucceedsOrFailsWithDriver(configNameOverrideIfSkipped string,
 
 	fmt.Println("FAIL")
 	errorMessage = fmt.Sprintf("   %s", errorMessage)
-	if isConfiguredToWarn || treatAsWarning {
+	if isConfiguredToWarn {
 		fmt.Println(errorMessage)
 	} else {
 		atexit.ExitWithMessage(1, errorMessage)
@@ -325,6 +360,7 @@ func checkLibvirtDefaultNetworkExists() bool {
 func checkLibvirtDefaultNetworkActive() bool {
 	cmd := exec.Command("virsh", "--connect", "qemu:///system", "net-list")
 	cmd.Env = cmdUtils.ReplaceEnv(os.Environ(), "LC_ALL", "C")
+	cmd.Env = cmdUtils.ReplaceEnv(cmd.Env, "LANG", "C")
 	stdOutStdError, err := cmd.CombinedOutput()
 	if err != nil {
 		return false
@@ -347,34 +383,76 @@ func checkLibvirtDefaultNetworkActive() bool {
 
 // checkHypervDriverSwitch returns true if Virtual Switch has been selected
 func checkHypervDriverSwitch() bool {
-	switchEnv := os.Getenv("HYPERV_VIRTUAL_SWITCH")
-	if switchEnv == "" {
+	switchEnvName := "HYPERV_VIRTUAL_SWITCH"
+	posh := powershell.New()
+	defer posh.Close()
+
+	switchEnvValue := os.Getenv(switchEnvName)
+
+	if switchEnvValue == "" {
+		checkIfDefaultSwitchExists := `Get-VMSwitch -Id c08cb7b8-9b3c-408e-8e30-5e16a3aeb444 | ForEach-Object { $_.SwitchType }`
+		fmt.Printf("\n   'Default Switch' ... ")
+		stdOut, _ := posh.Execute(checkIfDefaultSwitchExists)
+		if strings.Contains(stdOut, "Internal") {
+
+			// force setting the environment variable
+			os.Setenv("HYPERV_VIRTUAL_SWITCH", "Default Switch")
+			return true
+		}
+
 		return false
 	}
 
-	return true
+	if switchEnvValue != "" {
+		checkIfVirtualSwitchExists := fmt.Sprintf("Get-VMSwitch %s| ForEach-Object { $_.SwitchType }", switchEnvValue)
+		fmt.Printf(fmt.Sprintf("\n   '%s' ... ", switchEnvValue))
+		stdOut, _ := posh.Execute(checkIfVirtualSwitchExists)
+		if strings.Contains(stdOut, "Get-VMSwitch") {
+			return false // error returned
+		}
+
+		return true
+	}
+
+	return false
 }
 
 // checkHypervDriverInstalled returns true if Hyper-V driver is installed
 func checkHypervDriverInstalled() bool {
-	posh := powershell.New()
-
-	checkIfHyperVInstalled := `@(Get-Command Get-VM).ModuleName`
-	stdOut, _ := posh.Execute(checkIfHyperVInstalled)
-	if !strings.Contains(stdOut, "Hyper-V") {
+	// Check if Hyper-V's Virtual Machine Management Service is installed
+	_, err := exec.LookPath("vmms.exe")
+	if err != nil {
 		return false
 	}
+
+	// check to see if a hypervisor is present. if hyper-v is installed and enabled,
+	posh := powershell.New()
+	defer posh.Close()
+
+	checkHypervisorPresent := `@(Get-Wmiobject Win32_ComputerSystem).HypervisorPresent`
+
+	stdOut, _ := posh.Execute(checkHypervisorPresent)
+	if !strings.Contains(stdOut, "True") {
+		return false
+	}
+
 	return true
 }
 
 // checkHypervDriverUser returns true if user is member of Hyper-V admin
 func checkHypervDriverUser() bool {
 	posh := powershell.New()
+	defer posh.Close()
 
 	// Use RID to prevent issues with localized groups: https://github.com/minishift/minishift/issues/1541
 	// https://support.microsoft.com/en-us/help/243330/well-known-security-identifiers-in-windows-operating-systems
 	// BUILTIN\Hyper-V Administrators => S-1-5-32-578
-	checkIfMemberOfHyperVAdmins := `@([Security.Principal.WindowsPrincipal][Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole("S-1-5-32-578")`
+
+	//Hyper-V Administrators group check fails: https://github.com/minishift/minishift/issues/2047
+	//Using SecurityIdentifier overload of IsInRole()
+	checkIfMemberOfHyperVAdmins :=
+		`$sid = New-Object System.Security.Principal.SecurityIdentifier("S-1-5-32-578")
+	@([Security.Principal.WindowsPrincipal][Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole($sid)`
 	stdOut, _ := posh.Execute(checkIfMemberOfHyperVAdmins)
 	if !strings.Contains(stdOut, "True") {
 		return false
@@ -394,36 +472,35 @@ func checkInstanceIP(driver drivers.Driver) bool {
 	return false
 }
 
+// checkNameservers will return true if the instance has nameservers
+func checkNameservers(driver drivers.Driver) bool {
+	return minishiftNetwork.HasNameserversConfigured(driver)
+}
+
 // checkIPConnectivity checks if the VM has connectivity to the outside network
 func checkIPConnectivity(driver drivers.Driver) bool {
 	ipToPing := viper.GetString(configCmd.CheckNetworkPingHost.Name)
-	if ipToPing == "" {
-		ipToPing = "8.8.8.8"
-	}
 
 	fmt.Printf("\n   Pinging %s ... ", ipToPing)
-	return minishiftUtil.IsIPReachable(driver, ipToPing, false)
+	return minishiftNetwork.IsIPReachable(driver, ipToPing, false)
 }
 
 // checkHttpConnectivity allows to test outside connectivity and possible proxy support
 func checkHttpConnectivity(driver drivers.Driver) bool {
 	urlToRetrieve := viper.GetString(configCmd.CheckNetworkHttpHost.Name)
-	if urlToRetrieve == "" {
-		urlToRetrieve = "http://minishift.io/index.html"
-	}
 
 	fmt.Printf("\n   Retrieving %s ... ", urlToRetrieve)
-	return minishiftUtil.IsRetrievable(driver, urlToRetrieve, false)
+	return minishiftNetwork.IsRetrievable(driver, urlToRetrieve, false)
 }
 
-// checkStorageMounted checks if the peristent storage volume, storageDisk, is
+// checkStorageMounted checks if the persistent storage volume, storageDisk, is
 // mounted to the VM instance
 func checkStorageMounted(driver drivers.Driver) bool {
 	mounted, _ := isMounted(driver, StorageDisk)
 	return mounted
 }
 
-// checkStorageUsage checks if the peristent storage volume has enough storage
+// checkStorageUsage checks if the persistent storage volume has enough storage
 // space available.
 func checkStorageUsage(driver drivers.Driver) bool {
 	_, usedPercentage := getDiskUsage(driver, StorageDisk)
@@ -480,39 +557,11 @@ func isMounted(driver drivers.Driver, mountpoint string) (bool, error) {
 // checkIsoUrl checks the Iso url and returns true if the iso file exists
 func checkIsoURL() bool {
 	isoUrl := viper.GetString(configCmd.ISOUrl.Name)
-	for _, isoAlias := range constants.ValidIsoAliases {
-		if isoUrl == isoAlias {
-			return true
-		}
-	}
-
-	if !strings.HasSuffix(isoUrl, ".iso") {
+	err := validations.IsValidISOUrl(configCmd.ISOUrl.Name, isoUrl)
+	if err != nil {
 		return false
 	}
-
-	match, _ := regexp.MatchString(`^https?://`, isoUrl)
-	if match {
-		return true
-	}
-
-	if runtime.GOOS == "windows" {
-		match, _ := regexp.MatchString("^file://[a-zA-Z]:/.+", isoUrl)
-		if !match {
-			return false
-		}
-		if filehelper.Exists(strings.Replace(strings.TrimPrefix(isoUrl, "file://"), "/", "\\", -1)) {
-			return true
-		}
-	} else {
-		match, _ := regexp.MatchString("^file:///.+", isoUrl)
-		if !match {
-			return false
-		}
-		if filehelper.Exists(strings.TrimPrefix(isoUrl, "file://")) {
-			return true
-		}
-	}
-	return false
+	return true
 }
 
 func checkVMDriver() bool {
@@ -522,3 +571,39 @@ func checkVMDriver() bool {
 	}
 	return true
 }
+
+func validateOpenshiftVersion() bool {
+	requestedVersion := viper.GetString(configCmd.OpenshiftVersion.Name)
+
+	valid, err := openshiftVersion.IsGreaterOrEqualToBaseVersion(requestedVersion, constants.MinimumSupportedOpenShiftVersion)
+	if err != nil {
+		return false
+	}
+
+	if !valid {
+		return false
+	}
+	return true
+}
+
+// checkOriginRelease return true if specified version of OpenShift is released
+func checkOriginRelease() bool {
+	client := github.Client()
+	_, _, err := client.Repositories.GetReleaseByTag("openshift", "origin", viper.GetString(configCmd.OpenshiftVersion.Name))
+	if err != nil {
+		return false
+	}
+	return true
+}
+
+// checkOCPRelease return true if specified version of OpenShift is released
+func checkOCPRelease() bool {
+	version := viper.GetString(configCmd.OpenshiftVersion.Name)
+	// use MinimumOcBinaryVersion if version < MinimumOcBinaryVersion
+	if util.VersionOrdinal(version) < util.VersionOrdinal(minikubeConstants.MinimumOcBinaryVersion) {
+		version = minikubeConstants.MinimumOcBinaryVersion
+	}
+
+	version = strings.TrimPrefix(version, "v")
+	return util.IsOcpVersionAvailable(version)
+}
