@@ -26,17 +26,21 @@ type Command interface {
 	String() string
 }
 
-type doExecute func(ec *ExecutionContext) error
+type doExecute func(ec *ExecutionContext, ignoreError bool) error
 
 type defaultCommand struct {
 	Command
 
-	rawCommand string
-	fn         doExecute
+	rawCommand  string
+	fn          doExecute
+	ignoreError bool
 }
 
 func (c *defaultCommand) Execute(ec *ExecutionContext) error {
-	err := c.fn(ec)
+	err := c.fn(ec, c.ignoreError)
+	if c.ignoreError {
+		return nil
+	}
 	if err != nil {
 		return err
 	}
@@ -46,3 +50,7 @@ func (c *defaultCommand) Execute(ec *ExecutionContext) error {
 func (c *defaultCommand) String() string {
 	return c.rawCommand
 }
+
+func (c *defaultCommand) IgnoreError() bool {
+	return c.ignoreError
+}
