@@ -28,21 +28,21 @@ type OpenShiftCommand struct {
 	*defaultCommand
 }
 
-func NewOpenShiftCommand(command string) *OpenShiftCommand {
-	defaultCommand := &defaultCommand{rawCommand: command}
+func NewOpenShiftCommand(command string, ignoreError bool) *OpenShiftCommand {
+	defaultCommand := &defaultCommand{rawCommand: command, ignoreError: ignoreError}
 	openShiftCommand := &OpenShiftCommand{defaultCommand}
 	defaultCommand.fn = openShiftCommand.doExecute
 	return openShiftCommand
 }
 
-func (c *OpenShiftCommand) doExecute(ec *ExecutionContext) error {
-	// split off the actual 'oc' command. We are using our cached oc version to run oc commands
+func (c *OpenShiftCommand) doExecute(ec *ExecutionContext, ignoreError bool) error {
+	// split off the actual 'openshift' command. We are using origin container to run those commands
 	cmd := strings.Replace(c.rawCommand, "openshift ", "", 1)
 	cmd = ec.Interpolate(cmd)
 	fmt.Print(".")
 
 	commander := ec.GetDockerCommander()
-	_, err := commander.Exec("-t", constants.OpenshiftContainerName, constants.OpenshiftExec, ec.Interpolate(cmd))
+	_, err := commander.Exec("-t", constants.OpenshiftContainerName, constants.OpenshiftOcExec, ec.Interpolate(cmd))
 	if err != nil {
 		return errors.New(fmt.Sprintf("Error executing command '%s':", err.Error()))
 	}
