@@ -18,6 +18,7 @@ package config
 
 import (
 	"encoding/json"
+	"github.com/minishift/minishift/pkg/minishift/hostfolder/config"
 	"io/ioutil"
 	"os"
 )
@@ -25,18 +26,21 @@ import (
 var InstanceConfig *InstanceConfigType
 
 type InstanceConfigType struct {
-	FilePath     string `json:"-"`
-	OcPath       string
-	IsRegistered bool
-	IsRHELBased  bool
+	FilePath                  string `json:"-"`
+	OcPath                    string // minishift state
+	IsRegistered              bool   // minishift state
+	IsRHELBased               bool   // minishift state
+	SupportsNetworkAssignment bool   // minishift state
 
-	HostFolders []HostFolder
+	HostFolders []config.HostFolderConfig
+
+	VMDriver string // general config
 }
 
 // Create new object with data if file exists or
 // Create json file and return object if doesn't exists
 func NewInstanceConfig(path string) (*InstanceConfigType, error) {
-	cfg := &InstanceConfigType{HostFolders: []HostFolder{}}
+	cfg := &InstanceConfigType{HostFolders: []config.HostFolderConfig{}}
 	cfg.FilePath = path
 
 	// Check json file existence
