@@ -22,10 +22,11 @@ const (
 	MinikubeIsoAlias       = "minikube"
 	OpenshiftContainerName = "origin"
 	OpenshiftExec          = "/usr/bin/openshift"
+	OpenshiftOcExec        = "/usr/bin/oc"
 	DefaultProject         = "myproject"
 	DefaultUser            = "developer"
 )
 
 var (
-	ValidIsoAliases = []string{"b2d", "centos", "minikube"}
+	ValidIsoAliases = []string{B2dIsoAlias, CentOsIsoAlias, MinikubeIsoAlias}
 )
