@@ -30,6 +30,11 @@ func New() *PowerShell {
 		powerShell: createPowerShell(),
 	}
 }
+
+func (p *PowerShell) Close() {
+	p.powerShell.Exit()
+}
+
 func (p *PowerShell) Execute(command string) (stdOut string, stdErr string) {
 	stdOut, stdErr, _ = p.powerShell.Execute(command)
 	return
