@@ -36,6 +36,8 @@ import (
 	"github.com/minishift/minishift/pkg/util/archive"
 	pb "gopkg.in/cheggaaa/pb.v1"
 
+	"github.com/kardianos/osext"
+	"github.com/minishift/minishift/pkg/util"
 	githubutils "github.com/minishift/minishift/pkg/util/github"
 	"github.com/minishift/minishift/pkg/version"
 )
@@ -78,6 +80,11 @@ func IsNewerVersion(localVersion, latestVersion semver.Version) bool {
 func Update(latestVersion semver.Version) error {
 	var extName string
 
+	path, _ := osext.Executable()
+	if writable := util.IsDirectoryWritable(filepath.Dir(path)); !writable {
+		return fmt.Errorf("Directory '%s' doesn't have write permission.\nPlease fix the permission issue and try running the command again.", filepath.Dir(path))
+	}
+
 	// Temporary directory to store archive contents
 	tmpDir, err := ioutil.TempDir("", "download")
 	defer os.RemoveAll(tmpDir)
@@ -149,7 +156,7 @@ func downloadAndVerifyArchive(url, tmpDir string) (string, error) {
 
 	httpResp, err := http.Get(url)
 	if err != nil {
-		return "", errors.New(fmt.Sprintf("Cannot download archive from %s: %s", url, err))
+		return "", errors.New(fmt.Sprintf("Cannot download archive from '%s': %s", url, err))
 	}
 	defer func() { _ = httpResp.Body.Close() }()
 
